summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pminserterrordialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pminserterrordialog.h')
-rw-r--r--kpovmodeler/pminserterrordialog.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pminserterrordialog.h b/kpovmodeler/pminserterrordialog.h
index 9a2c1d2e..09eb32dd 100644
--- a/kpovmodeler/pminserterrordialog.h
+++ b/kpovmodeler/pminserterrordialog.h
@@ -36,13 +36,14 @@ class TQLabel;
class PMInsertErrorDialog : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Creates a modal PMInsertErrorDialog with parent and name.
*/
PMInsertErrorDialog( int NumberOfObjects, int NumberOfInsertErrors,
const TQStringList& details,
- TQWidget* parent = 0, const char* name = 0 );
+ TQWidget* tqparent = 0, const char* name = 0 );
protected slots:
void slotUser1( );
@@ -36,13 +36,14 @@ class TQLabel;
public:
/**
- * Creates a modal PMInsertErrorDialog with parent and name.
+ * Creates a modal PMInsertErrorDialog with tqparent and name.
*/
PMInsertErrorDialog( int NumberOfObjects, int NumberOfInsertErrors,